pub struct UpdateCapacityReservationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateCapacityReservation.
Updates the number of requested data processing units for the capacity reservation with the specified name.
Implementations
Sourceimpl UpdateCapacityReservationFluentBuilder
impl UpdateCapacityReservationFluentBuilder
Sourcepub fn as_input(&self) -> &UpdateCapacityReservationInputBuilder
pub fn as_input(&self) -> &UpdateCapacityReservationInputBuilder
Access the UpdateCapacityReservation as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdateCapacityReservationOutput, SdkError<UpdateCapacityReservationError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdateCapacityReservationOutput, SdkError<UpdateCapacityReservationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdateCapacityReservationOutput, UpdateCapacityReservationError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdateCapacityReservationOutput, UpdateCapacityReservationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn target_dpus(self, input: i32) -> Self
pub fn target_dpus(self, input: i32) -> Self
The new number of requested data processing units.
Sourcepub fn set_target_dpus(self, input: Option<i32>) -> Self
pub fn set_target_dpus(self, input: Option<i32>) -> Self
The new number of requested data processing units.
Sourcepub fn get_target_dpus(&self) -> &Option<i32>
pub fn get_target_dpus(&self) -> &Option<i32>
The new number of requested data processing units.